@@ -45,7 +45,6 @@
 #include <IlmThreadMutex.h>
 #include <IlmThreadSemaphore.h>
 #include <ImfThreading.h>
-#include <ImathRandom.h>
 
 #include <stdio.h>
 #include <assert.h>
@@ -244,7 +243,8 @@ writeReadRGBA (const char fileName[],
 
         cout << "comparing " << endl;
 
-	if (in.compression() == B44_COMPRESSION)
+	if (in.compression() == B44_COMPRESSION ||
+	    in.compression() == B44A_COMPRESSION)
 	{
 	    compareB44 (width, height, p1, p2, channels);
 	}
